# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/Users/daniel/Documents/GitHub/StructureFinder/structurefinder/gui/strf_main.ui'
#
# Created by: PyQt5 UI code generator 5.15.7
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_stdbMainwindow(object):
    def setupUi(self, stdbMainwindow):
        stdbMainwindow.setObjectName("stdbMainwindow")
        stdbMainwindow.resize(1291, 853)
        self.centralwidget = QtWidgets.QWidget(stdbMainwindow)
        self.centralwidget.setObjectName("centralwidget")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.centralwidget)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.groupBox = QtWidgets.QGroupBox(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox.sizePolicy().hasHeightForWidth())
        self.groupBox.setSizePolicy(sizePolicy)
        self.groupBox.setTitle("")
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.importDirButton = QtWidgets.QPushButton(self.groupBox)
        self.importDirButton.setMinimumSize(QtCore.QSize(185, 0))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.importDirButton.setFont(font)
        self.importDirButton.setObjectName("importDirButton")
        self.verticalLayout_10.addWidget(self.importDirButton, 0, QtCore.Qt.AlignLeft)
        self.appendDirButton = QtWidgets.QPushButton(self.groupBox)
        self.appendDirButton.setMinimumSize(QtCore.QSize(185, 0))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.appendDirButton.setFont(font)
        self.appendDirButton.setObjectName("appendDirButton")
        self.verticalLayout_10.addWidget(self.appendDirButton, 0, QtCore.Qt.AlignLeft)
        self.add_cif = QtWidgets.QCheckBox(self.groupBox)
        self.add_cif.setChecked(True)
        self.add_cif.setObjectName("add_cif")
        self.verticalLayout_10.addWidget(self.add_cif)
        self.add_res = QtWidgets.QCheckBox(self.groupBox)
        self.add_res.setChecked(True)
        self.add_res.setObjectName("add_res")
        self.verticalLayout_10.addWidget(self.add_res)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        self.verticalLayout_10.addItem(spacerItem)
        self.importDatabaseButton = QtWidgets.QPushButton(self.groupBox)
        self.importDatabaseButton.setMinimumSize(QtCore.QSize(185, 0))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.importDatabaseButton.setFont(font)
        self.importDatabaseButton.setObjectName("importDatabaseButton")
        self.verticalLayout_10.addWidget(self.importDatabaseButton, 0, QtCore.Qt.AlignLeft)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        self.verticalLayout_10.addItem(spacerItem1)
        self.saveDatabaseButton = QtWidgets.QPushButton(self.groupBox)
        self.saveDatabaseButton.setMinimumSize(QtCore.QSize(185, 0))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.saveDatabaseButton.setFont(font)
        self.saveDatabaseButton.setObjectName("saveDatabaseButton")
        self.verticalLayout_10.addWidget(self.saveDatabaseButton, 0, QtCore.Qt.AlignLeft)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        self.verticalLayout_10.addItem(spacerItem2)
        self.appendDatabasePushButton = QtWidgets.QPushButton(self.groupBox)
        self.appendDatabasePushButton.setMinimumSize(QtCore.QSize(185, 0))
        self.appendDatabasePushButton.setObjectName("appendDatabasePushButton")
        self.verticalLayout_10.addWidget(self.appendDatabasePushButton)
        spacerItem3 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        self.verticalLayout_10.addItem(spacerItem3)
        self.p4pCellButton = QtWidgets.QPushButton(self.groupBox)
        self.p4pCellButton.setMinimumSize(QtCore.QSize(185, 0))
        self.p4pCellButton.setObjectName("p4pCellButton")
        self.verticalLayout_10.addWidget(self.p4pCellButton, 0, QtCore.Qt.AlignLeft)
        spacerItem4 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_10.addItem(spacerItem4)
        self.closeDatabaseButton = QtWidgets.QPushButton(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.closeDatabaseButton.sizePolicy().hasHeightForWidth())
        self.closeDatabaseButton.setSizePolicy(sizePolicy)
        self.closeDatabaseButton.setMinimumSize(QtCore.QSize(185, 0))
        self.closeDatabaseButton.setObjectName("closeDatabaseButton")
        self.verticalLayout_10.addWidget(self.closeDatabaseButton, 0, QtCore.Qt.AlignLeft)
        self.horizontalLayout_5.addWidget(self.groupBox)
        self.verticalLayout_6 = QtWidgets.QVBoxLayout()
        self.verticalLayout_6.setContentsMargins(-1, -1, 0, -1)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.MaintabWidget = QtWidgets.QTabWidget(self.centralwidget)
        self.MaintabWidget.setAccessibleName("")
        self.MaintabWidget.setAccessibleDescription("")
        self.MaintabWidget.setAutoFillBackground(False)
        self.MaintabWidget.setStyleSheet("")
        self.MaintabWidget.setObjectName("MaintabWidget")
        self.maintab = QtWidgets.QWidget()
        self.maintab.setObjectName("maintab")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.maintab)
        self.gridLayout_3.setContentsMargins(10, -1, 10, 10)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.importResults = QtWidgets.QGridLayout()
        self.importResults.setSizeConstraint(QtWidgets.QLayout.SetNoConstraint)
        self.importResults.setObjectName("importResults")
        spacerItem5 = QtWidgets.QSpacerItem(5, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.importResults.addItem(spacerItem5, 2, 1, 1, 1)
        self.groupBox_2 = QtWidgets.QGroupBox(self.maintab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(2)
        sizePolicy.setVerticalStretch(2)
        sizePolicy.setHeightForWidth(self.groupBox_2.sizePolicy().hasHeightForWidth())
        self.groupBox_2.setSizePolicy(sizePolicy)
        self.groupBox_2.setMinimumSize(QtCore.QSize(200, 0))
        self.groupBox_2.setTitle("")
        self.groupBox_2.setObjectName("groupBox_2")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.groupBox_2)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formLayout_3 = QtWidgets.QFormLayout()
        self.formLayout_3.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.formLayout_3.setObjectName("formLayout_3")
        self.SpaceGrouplabel = QtWidgets.QLabel(self.groupBox_2)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.SpaceGrouplabel.setFont(font)
        self.SpaceGrouplabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.SpaceGrouplabel.setObjectName("SpaceGrouplabel")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.SpaceGrouplabel)
        self.SpaceGroupLineEdit = QtWidgets.QLineEdit(self.groupBox_2)
        self.SpaceGroupLineEdit.setMinimumSize(QtCore.QSize(0, 0))
        self.SpaceGroupLineEdit.setReadOnly(True)
        self.SpaceGroupLineEdit.setObjectName("SpaceGroupLineEdit")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.SpaceGroupLineEdit)
        self.zLabel = QtWidgets.QLabel(self.groupBox_2)
        self.zLabel.setObjectName("zLabel")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.zLabel)
        self.zLineEdit = QtWidgets.QLineEdit(self.groupBox_2)
        self.zLineEdit.setReadOnly(True)
        self.zLineEdit.setObjectName("zLineEdit")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.zLineEdit)
        self.temperatureLabel = QtWidgets.QLabel(self.groupBox_2)
        self.temperatureLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.temperatureLabel.setObjectName("temperatureLabel")
        self.formLayout_3.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.temperatureLabel)
        self.temperatureLineEdit = QtWidgets.QLineEdit(self.groupBox_2)
        self.temperatureLineEdit.setReadOnly(True)
        self.temperatureLineEdit.setObjectName("temperatureLineEdit")
        self.formLayout_3.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.temperatureLineEdit)
        self.wR2Label = QtWidgets.QLabel(self.groupBox_2)
        font = QtGui.QFont()
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        self.wR2Label.setFont(font)
        self.wR2Label.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.wR2Label.setObjectName("wR2Label")
        self.formLayout_3.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.wR2Label)
        self.wR2LineEdit = QtWidgets.QLineEdit(self.groupBox_2)
        self.wR2LineEdit.setReadOnly(True)
        self.wR2LineEdit.setObjectName("wR2LineEdit")
        self.formLayout_3.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.wR2LineEdit)
        self.r1Label = QtWidgets.QLabel(self.groupBox_2)
        font = QtGui.QFont()
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        self.r1Label.setFont(font)
        self.r1Label.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.r1Label.setObjectName("r1Label")
        self.formLayout_3.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.r1Label)
        self.r1LineEdit = QtWidgets.QLineEdit(self.groupBox_2)
        self.r1LineEdit.setReadOnly(True)
        self.r1LineEdit.setObjectName("r1LineEdit")
        self.formLayout_3.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.r1LineEdit)
        self.goofLabel = QtWidgets.QLabel(self.groupBox_2)
        self.goofLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.goofLabel.setObjectName("goofLabel")
        self.formLayout_3.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.goofLabel)
        self.goofLineEdit = QtWidgets.QLineEdit(self.groupBox_2)
        self.goofLineEdit.setReadOnly(True)
        self.goofLineEdit.setObjectName("goofLineEdit")
        self.formLayout_3.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.goofLineEdit)
        self.maxShiftLabel = QtWidgets.QLabel(self.groupBox_2)
        self.maxShiftLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.maxShiftLabel.setObjectName("maxShiftLabel")
        self.formLayout_3.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.maxShiftLabel)
        self.maxShiftLineEdit = QtWidgets.QLineEdit(self.groupBox_2)
        self.maxShiftLineEdit.setReadOnly(True)
        self.maxShiftLineEdit.setObjectName("maxShiftLineEdit")
        self.formLayout_3.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.maxShiftLineEdit)
        self.peakLabel = QtWidgets.QLabel(self.groupBox_2)
        self.peakLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.peakLabel.setObjectName("peakLabel")
        self.formLayout_3.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.peakLabel)
        self.peakLineEdit = QtWidgets.QLineEdit(self.groupBox_2)
        self.peakLineEdit.setReadOnly(True)
        self.peakLineEdit.setObjectName("peakLineEdit")
        self.formLayout_3.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.peakLineEdit)
        self.rintLabel = QtWidgets.QLabel(self.groupBox_2)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.rintLabel.setFont(font)
        self.rintLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.rintLabel.setObjectName("rintLabel")
        self.formLayout_3.setWidget(8, QtWidgets.QFormLayout.LabelRole, self.rintLabel)
        self.rintLineEdit = QtWidgets.QLineEdit(self.groupBox_2)
        self.rintLineEdit.setReadOnly(True)
        self.rintLineEdit.setObjectName("rintLineEdit")
        self.formLayout_3.setWidget(8, QtWidgets.QFormLayout.FieldRole, self.rintLineEdit)
        self.rsigmaLabel = QtWidgets.QLabel(self.groupBox_2)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.rsigmaLabel.setFont(font)
        self.rsigmaLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.rsigmaLabel.setObjectName("rsigmaLabel")
        self.formLayout_3.setWidget(9, QtWidgets.QFormLayout.LabelRole, self.rsigmaLabel)
        self.rsigmaLineEdit = QtWidgets.QLineEdit(self.groupBox_2)
        self.rsigmaLineEdit.setReadOnly(True)
        self.rsigmaLineEdit.setObjectName("rsigmaLineEdit")
        self.formLayout_3.setWidget(9, QtWidgets.QFormLayout.FieldRole, self.rsigmaLineEdit)
        self.verticalLayout.addLayout(self.formLayout_3)
        self.importResults.addWidget(self.groupBox_2, 2, 2, 1, 1)
        self.groupBox_5 = QtWidgets.QGroupBox(self.maintab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(2)
        sizePolicy.setVerticalStretch(2)
        sizePolicy.setHeightForWidth(self.groupBox_5.sizePolicy().hasHeightForWidth())
        self.groupBox_5.setSizePolicy(sizePolicy)
        self.groupBox_5.setMinimumSize(QtCore.QSize(200, 0))
        self.groupBox_5.setTitle("")
        self.groupBox_5.setObjectName("groupBox_5")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.groupBox_5)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.CellLabel = QtWidgets.QLabel(self.groupBox_5)
        self.CellLabel.setMaximumSize(QtCore.QSize(16777215, 21))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.CellLabel.setFont(font)
        self.CellLabel.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.CellLabel.setObjectName("CellLabel")
        self.verticalLayout_3.addWidget(self.CellLabel)
        self.formLayout_2 = QtWidgets.QFormLayout()
        self.formLayout_2.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout_2.setObjectName("formLayout_2")
        self.label = QtWidgets.QLabel(self.groupBox_5)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label)
        self.SumformLabel = QtWidgets.QLabel(self.groupBox_5)
        self.SumformLabel.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.SumformLabel.sizePolicy().hasHeightForWidth())
        self.SumformLabel.setSizePolicy(sizePolicy)
        self.SumformLabel.setMinimumSize(QtCore.QSize(10, 42))
        font = QtGui.QFont()
        font.setPointSize(11)
        font.setKerning(False)
        self.SumformLabel.setFont(font)
        self.SumformLabel.setStyleSheet("background-color:  rgba(255, 255, 255, 255);")
        self.SumformLabel.setInputMethodHints(QtCore.Qt.ImhNone)
        self.SumformLabel.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.SumformLabel.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.SumformLabel.setLineWidth(1)
        self.SumformLabel.setMidLineWidth(0)
        self.SumformLabel.setText("")
        self.SumformLabel.setTextFormat(QtCore.Qt.AutoText)
        self.SumformLabel.setScaledContents(False)
        self.SumformLabel.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.SumformLabel.setWordWrap(True)
        self.SumformLabel.setOpenExternalLinks(False)
        self.SumformLabel.setTextInteractionFlags(QtCore.Qt.TextEditorInteraction)
        self.SumformLabel.setObjectName("SumformLabel")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.SumformLabel)
        self.reflTotalLabel = QtWidgets.QLabel(self.groupBox_5)
        self.reflTotalLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.reflTotalLabel.setObjectName("reflTotalLabel")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.reflTotalLabel)
        self.reflTotalLineEdit = QtWidgets.QLineEdit(self.groupBox_5)
        self.reflTotalLineEdit.setReadOnly(True)
        self.reflTotalLineEdit.setObjectName("reflTotalLineEdit")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.reflTotalLineEdit)
        self.uniqReflLabel = QtWidgets.QLabel(self.groupBox_5)
        self.uniqReflLabel.setObjectName("uniqReflLabel")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.uniqReflLabel)
        self.uniqReflLineEdit = QtWidgets.QLineEdit(self.groupBox_5)
        self.uniqReflLineEdit.setObjectName("uniqReflLineEdit")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.uniqReflLineEdit)
        self.refl2sigmaLabel = QtWidgets.QLabel(self.groupBox_5)
        self.refl2sigmaLabel.setObjectName("refl2sigmaLabel")
        self.formLayout_2.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.refl2sigmaLabel)
        self.refl2sigmaLineEdit = QtWidgets.QLineEdit(self.groupBox_5)
        self.refl2sigmaLineEdit.setObjectName("refl2sigmaLineEdit")
        self.formLayout_2.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.refl2sigmaLineEdit)
        self.wavelengthLabel = QtWidgets.QLabel(self.groupBox_5)
        self.wavelengthLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.wavelengthLabel.setObjectName("wavelengthLabel")
        self.formLayout_2.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.wavelengthLabel)
        self.wavelengthLineEdit = QtWidgets.QLineEdit(self.groupBox_5)
        self.wavelengthLineEdit.setReadOnly(True)
        self.wavelengthLineEdit.setObjectName("wavelengthLineEdit")
        self.formLayout_2.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.wavelengthLineEdit)
        self.cellField = QtWidgets.QLabel(self.groupBox_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cellField.sizePolicy().hasHeightForWidth())
        self.cellField.setSizePolicy(sizePolicy)
        self.cellField.setMinimumSize(QtCore.QSize(0, 70))
        self.cellField.setBaseSize(QtCore.QSize(0, 70))
        self.cellField.setContextMenuPolicy(QtCore.Qt.ActionsContextMenu)
        self.cellField.setAutoFillBackground(False)
        self.cellField.setStyleSheet("border-color: rgb(53, 53, 53);")
        self.cellField.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.cellField.setFrameShadow(QtWidgets.QFrame.Plain)
        self.cellField.setText("")
        self.cellField.setTextFormat(QtCore.Qt.RichText)
        self.cellField.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.cellField.setObjectName("cellField")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.SpanningRole, self.cellField)
        self.verticalLayout_3.addLayout(self.formLayout_2)
        spacerItem6 = QtWidgets.QSpacerItem(5, 10, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem6)
        self.ExportAsCIFpushButton = QtWidgets.QPushButton(self.groupBox_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ExportAsCIFpushButton.sizePolicy().hasHeightForWidth())
        self.ExportAsCIFpushButton.setSizePolicy(sizePolicy)
        self.ExportAsCIFpushButton.setObjectName("ExportAsCIFpushButton")
        self.verticalLayout_3.addWidget(self.ExportAsCIFpushButton, 0, QtCore.Qt.AlignLeft)
        self.importResults.addWidget(self.groupBox_5, 2, 0, 1, 1)
        self.molGroupBox = QtWidgets.QGroupBox(self.maintab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(2)
        sizePolicy.setVerticalStretch(3)
        sizePolicy.setHeightForWidth(self.molGroupBox.sizePolicy().hasHeightForWidth())
        self.molGroupBox.setSizePolicy(sizePolicy)
        self.molGroupBox.setMinimumSize(QtCore.QSize(200, 200))
        self.molGroupBox.setBaseSize(QtCore.QSize(240, 240))
        self.molGroupBox.setFlat(True)
        self.molGroupBox.setCheckable(False)
        self.molGroupBox.setObjectName("molGroupBox")
        self.ogllayout = QtWidgets.QVBoxLayout(self.molGroupBox)
        self.ogllayout.setContentsMargins(1, 5, 1, 1)
        self.ogllayout.setSpacing(6)
        self.ogllayout.setObjectName("ogllayout")
        self.render_widget = MoleculeWidget(self.molGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.render_widget.sizePolicy().hasHeightForWidth())
        self.render_widget.setSizePolicy(sizePolicy)
        self.render_widget.setObjectName("render_widget")
        self.ogllayout.addWidget(self.render_widget)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.growCheckBox = QtWidgets.QCheckBox(self.molGroupBox)
        self.growCheckBox.setObjectName("growCheckBox")
        self.horizontalLayout_6.addWidget(self.growCheckBox)
        self.labelsCheckBox = QtWidgets.QCheckBox(self.molGroupBox)
        self.labelsCheckBox.setObjectName("labelsCheckBox")
        self.horizontalLayout_6.addWidget(self.labelsCheckBox)
        self.ogllayout.addLayout(self.horizontalLayout_6)
        self.importResults.addWidget(self.molGroupBox, 2, 6, 1, 1)
        self.groupBox_3 = QtWidgets.QGroupBox(self.maintab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(2)
        sizePolicy.setVerticalStretch(2)
        sizePolicy.setHeightForWidth(self.groupBox_3.sizePolicy().hasHeightForWidth())
        self.groupBox_3.setSizePolicy(sizePolicy)
        self.groupBox_3.setMinimumSize(QtCore.QSize(200, 0))
        self.groupBox_3.setTitle("")
        self.groupBox_3.setObjectName("groupBox_3")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.groupBox_3)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.formLayout = QtWidgets.QFormLayout()
        self.formLayout.setObjectName("formLayout")
        self.numParametersLabel = QtWidgets.QLabel(self.groupBox_3)
        self.numParametersLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.numParametersLabel.setObjectName("numParametersLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.numParametersLabel)
        self.numParametersLineEdit = QtWidgets.QLineEdit(self.groupBox_3)
        self.numParametersLineEdit.setMinimumSize(QtCore.QSize(0, 0))
        self.numParametersLineEdit.setReadOnly(True)
        self.numParametersLineEdit.setObjectName("numParametersLineEdit")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.numParametersLineEdit)
        self.dataReflnsLabel = QtWidgets.QLabel(self.groupBox_3)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.dataReflnsLabel.setFont(font)
        self.dataReflnsLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.dataReflnsLabel.setObjectName("dataReflnsLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.dataReflnsLabel)
        self.dataReflnsLineEdit = QtWidgets.QLineEdit(self.groupBox_3)
        self.dataReflnsLineEdit.setReadOnly(True)
        self.dataReflnsLineEdit.setObjectName("dataReflnsLineEdit")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.dataReflnsLineEdit)
        self.numRestraintsLabel = QtWidgets.QLabel(self.groupBox_3)
        self.numRestraintsLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.numRestraintsLabel.setObjectName("numRestraintsLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.numRestraintsLabel)
        self.numRestraintsLineEdit = QtWidgets.QLineEdit(self.groupBox_3)
        self.numRestraintsLineEdit.setReadOnly(True)
        self.numRestraintsLineEdit.setObjectName("numRestraintsLineEdit")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.numRestraintsLineEdit)
        self.thetaMaxLabel = QtWidgets.QLabel(self.groupBox_3)
        self.thetaMaxLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.thetaMaxLabel.setObjectName("thetaMaxLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.thetaMaxLabel)
        self.thetaMaxLineEdit = QtWidgets.QLineEdit(self.groupBox_3)
        self.thetaMaxLineEdit.setReadOnly(True)
        self.thetaMaxLineEdit.setObjectName("thetaMaxLineEdit")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.thetaMaxLineEdit)
        self.thetaFullLabel = QtWidgets.QLabel(self.groupBox_3)
        self.thetaFullLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.thetaFullLabel.setObjectName("thetaFullLabel")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.thetaFullLabel)
        self.thetaFullLineEdit = QtWidgets.QLineEdit(self.groupBox_3)
        self.thetaFullLineEdit.setReadOnly(True)
        self.thetaFullLineEdit.setObjectName("thetaFullLineEdit")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.thetaFullLineEdit)
        self.dLabel = QtWidgets.QLabel(self.groupBox_3)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.dLabel.setFont(font)
        self.dLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.dLabel.setObjectName("dLabel")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.dLabel)
        self.dLineEdit = QtWidgets.QLineEdit(self.groupBox_3)
        self.dLineEdit.setReadOnly(True)
        self.dLineEdit.setObjectName("dLineEdit")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.dLineEdit)
        self.completeLabel = QtWidgets.QLabel(self.groupBox_3)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.completeLabel.setFont(font)
        self.completeLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.completeLabel.setObjectName("completeLabel")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.completeLabel)
        self.completeLineEdit = QtWidgets.QLineEdit(self.groupBox_3)
        self.completeLineEdit.setReadOnly(True)
        self.completeLineEdit.setObjectName("completeLineEdit")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.completeLineEdit)
        self.cCDCNumberLabel = QtWidgets.QLabel(self.groupBox_3)
        self.cCDCNumberLabel.setObjectName("cCDCNumberLabel")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.cCDCNumberLabel)
        self.cCDCNumberLineEdit = QtWidgets.QLineEdit(self.groupBox_3)
        self.cCDCNumberLineEdit.setReadOnly(True)
        self.cCDCNumberLineEdit.setObjectName("cCDCNumberLineEdit")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.cCDCNumberLineEdit)
        self.lastModifiedLabel = QtWidgets.QLabel(self.groupBox_3)
        self.lastModifiedLabel.setObjectName("lastModifiedLabel")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.LabelRole, self.lastModifiedLabel)
        self.lastModifiedLineEdit = QtWidgets.QLineEdit(self.groupBox_3)
        self.lastModifiedLineEdit.setReadOnly(True)
        self.lastModifiedLineEdit.setObjectName("lastModifiedLineEdit")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.FieldRole, self.lastModifiedLineEdit)
        self.flackXLabel = QtWidgets.QLabel(self.groupBox_3)
        self.flackXLabel.setObjectName("flackXLabel")
        self.formLayout.setWidget(9, QtWidgets.QFormLayout.LabelRole, self.flackXLabel)
        self.flackXLineEdit = QtWidgets.QLineEdit(self.groupBox_3)
        self.flackXLineEdit.setObjectName("flackXLineEdit")
        self.formLayout.setWidget(9, QtWidgets.QFormLayout.FieldRole, self.flackXLineEdit)
        self.verticalLayout_2.addLayout(self.formLayout)
        self.importResults.addWidget(self.groupBox_3, 2, 4, 1, 1)
        spacerItem7 = QtWidgets.QSpacerItem(5, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.importResults.addItem(spacerItem7, 2, 5, 1, 1)
        self.searchLayout = QtWidgets.QHBoxLayout()
        self.searchLayout.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.searchLayout.setObjectName("searchLayout")
        self.searchLabel = QtWidgets.QLabel(self.maintab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.searchLabel.sizePolicy().hasHeightForWidth())
        self.searchLabel.setSizePolicy(sizePolicy)
        self.searchLabel.setObjectName("searchLabel")
        self.searchLayout.addWidget(self.searchLabel)
        self.searchCellLineEDit = QtWidgets.QLineEdit(self.maintab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(3)
        sizePolicy.setHeightForWidth(self.searchCellLineEDit.sizePolicy().hasHeightForWidth())
        self.searchCellLineEDit.setSizePolicy(sizePolicy)
        self.searchCellLineEDit.setDragEnabled(True)
        self.searchCellLineEDit.setClearButtonEnabled(True)
        self.searchCellLineEDit.setObjectName("searchCellLineEDit")
        self.searchLayout.addWidget(self.searchCellLineEDit)
        self.moreResultsCheckBox = QtWidgets.QCheckBox(self.maintab)
        self.moreResultsCheckBox.setObjectName("moreResultsCheckBox")
        self.searchLayout.addWidget(self.moreResultsCheckBox)
        self.sublattCheckbox = QtWidgets.QCheckBox(self.maintab)
        self.sublattCheckbox.setObjectName("sublattCheckbox")
        self.searchLayout.addWidget(self.sublattCheckbox)
        self.line = QtWidgets.QFrame(self.maintab)
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.searchLayout.addWidget(self.line)
        self.txtSearchLabel = QtWidgets.QLabel(self.maintab)
        self.txtSearchLabel.setObjectName("txtSearchLabel")
        self.searchLayout.addWidget(self.txtSearchLabel)
        self.txtSearchEdit = QtWidgets.QLineEdit(self.maintab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.txtSearchEdit.sizePolicy().hasHeightForWidth())
        self.txtSearchEdit.setSizePolicy(sizePolicy)
        self.txtSearchEdit.setObjectName("txtSearchEdit")
        self.searchLayout.addWidget(self.txtSearchEdit)
        self.importResults.addLayout(self.searchLayout, 0, 0, 1, 7)
        spacerItem8 = QtWidgets.QSpacerItem(5, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.importResults.addItem(spacerItem8, 2, 3, 1, 1)
        self.cifList_tableView = StructuresListTableView(self.maintab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(3)
        sizePolicy.setHeightForWidth(self.cifList_tableView.sizePolicy().hasHeightForWidth())
        self.cifList_tableView.setSizePolicy(sizePolicy)
        self.cifList_tableView.setStatusTip("")
        self.cifList_tableView.setAutoFillBackground(False)
        self.cifList_tableView.setStyleSheet("background-color: rgb(255, 255, 255);")
        self.cifList_tableView.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAsNeeded)
        self.cifList_tableView.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOn)
        self.cifList_tableView.setSizeAdjustPolicy(QtWidgets.QAbstractScrollArea.AdjustIgnored)
        self.cifList_tableView.setAutoScroll(True)
        self.cifList_tableView.setAutoScrollMargin(16)
        self.cifList_tableView.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.cifList_tableView.setProperty("showDropIndicator", True)
        self.cifList_tableView.setDragDropMode(QtWidgets.QAbstractItemView.DropOnly)
        self.cifList_tableView.setAlternatingRowColors(True)
        self.cifList_tableView.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)
        self.cifList_tableView.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.cifList_tableView.setTextElideMode(QtCore.Qt.ElideLeft)
        self.cifList_tableView.setSortingEnabled(True)
        self.cifList_tableView.setObjectName("cifList_tableView")
        self.cifList_tableView.horizontalHeader().setCascadingSectionResizes(True)
        self.cifList_tableView.horizontalHeader().setDefaultSectionSize(250)
        self.cifList_tableView.horizontalHeader().setMinimumSectionSize(90)
        self.cifList_tableView.horizontalHeader().setStretchLastSection(True)
        self.importResults.addWidget(self.cifList_tableView, 1, 0, 1, 7)
        self.gridLayout_3.addLayout(self.importResults, 0, 0, 1, 1)
        self.MaintabWidget.addTab(self.maintab, "")
        self.allEntrysTab = QtWidgets.QWidget()
        self.allEntrysTab.setObjectName("allEntrysTab")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.allEntrysTab)
        self.verticalLayout_8.setContentsMargins(10, -1, 10, 10)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.allCifTreeWidget = QtWidgets.QTreeWidget(self.allEntrysTab)
        self.allCifTreeWidget.setContextMenuPolicy(QtCore.Qt.ActionsContextMenu)
        self.allCifTreeWidget.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.allCifTreeWidget.setVerticalScrollMode(QtWidgets.QAbstractItemView.ScrollPerPixel)
        self.allCifTreeWidget.setAllColumnsShowFocus(False)
        self.allCifTreeWidget.setObjectName("allCifTreeWidget")
        self.verticalLayout_7.addWidget(self.allCifTreeWidget)
        self.verticalLayout_8.addLayout(self.verticalLayout_7)
        self.MaintabWidget.addTab(self.allEntrysTab, "")
        self.SHELXtab = QtWidgets.QWidget()
        self.SHELXtab.setObjectName("SHELXtab")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.SHELXtab)
        self.horizontalLayout_4.setContentsMargins(10, -1, 10, 10)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.SHELXplainTextEdit = QtWidgets.QPlainTextEdit(self.SHELXtab)
        self.SHELXplainTextEdit.setStyleSheet("")
        self.SHELXplainTextEdit.setObjectName("SHELXplainTextEdit")
        self.horizontalLayout_4.addWidget(self.SHELXplainTextEdit)
        self.MaintabWidget.addTab(self.SHELXtab, "")
        self.adv_searchtab = QtWidgets.QWidget()
        self.adv_searchtab.setObjectName("adv_searchtab")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.adv_searchtab)
        self.horizontalLayout.setContentsMargins(10, -1, 10, 10)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.gridLayout_6 = QtWidgets.QGridLayout()
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.NotContainsLabel = QtWidgets.QLabel(self.adv_searchtab)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.NotContainsLabel.setFont(font)
        self.NotContainsLabel.setAutoFillBackground(False)
        self.NotContainsLabel.setStyleSheet("background-color: rgb(254, 201, 205);")
        self.NotContainsLabel.setTextFormat(QtCore.Qt.AutoText)
        self.NotContainsLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.NotContainsLabel.setObjectName("NotContainsLabel")
        self.gridLayout_6.addWidget(self.NotContainsLabel, 0, 2, 1, 1)
        self.line_2 = QtWidgets.QFrame(self.adv_searchtab)
        self.line_2.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.gridLayout_6.addWidget(self.line_2, 0, 1, 3, 1)
        spacerItem9 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_6.addItem(spacerItem9, 6, 0, 1, 1)
        self.gridLayout_7 = QtWidgets.QGridLayout()
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.adv_elementsExclLineEdit = QtWidgets.QLineEdit(self.adv_searchtab)
        self.adv_elementsExclLineEdit.setObjectName("adv_elementsExclLineEdit")
        self.gridLayout_7.addWidget(self.adv_elementsExclLineEdit, 1, 1, 1, 1)
        self.elementsExcludedLabel_2 = QtWidgets.QLabel(self.adv_searchtab)
        self.elementsExcludedLabel_2.setObjectName("elementsExcludedLabel_2")
        self.gridLayout_7.addWidget(self.elementsExcludedLabel_2, 1, 0, 1, 1)
        self.wR2Label_3 = QtWidgets.QLabel(self.adv_searchtab)
        self.wR2Label_3.setObjectName("wR2Label_3")
        self.gridLayout_7.addWidget(self.wR2Label_3, 2, 0, 1, 1)
        self.unitCellLabel_2 = QtWidgets.QLabel(self.adv_searchtab)
        self.unitCellLabel_2.setText("")
        self.unitCellLabel_2.setObjectName("unitCellLabel_2")
        self.gridLayout_7.addWidget(self.unitCellLabel_2, 0, 1, 1, 1)
        self.adv_textsearch_excl = QtWidgets.QLineEdit(self.adv_searchtab)
        self.adv_textsearch_excl.setObjectName("adv_textsearch_excl")
        self.gridLayout_7.addWidget(self.adv_textsearch_excl, 2, 1, 1, 1)
        self.gridLayout_6.addLayout(self.gridLayout_7, 1, 2, 1, 1)
        self.containsLabel = QtWidgets.QLabel(self.adv_searchtab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.containsLabel.sizePolicy().hasHeightForWidth())
        self.containsLabel.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.containsLabel.setFont(font)
        self.containsLabel.setStyleSheet("background-color: rgb(173, 255, 167);")
        self.containsLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.containsLabel.setObjectName("containsLabel")
        self.gridLayout_6.addWidget(self.containsLabel, 0, 0, 1, 1)
        self.gridLayout_4 = QtWidgets.QGridLayout()
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.adv_unitCellLineEdit = QtWidgets.QLineEdit(self.adv_searchtab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.adv_unitCellLineEdit.sizePolicy().hasHeightForWidth())
        self.adv_unitCellLineEdit.setSizePolicy(sizePolicy)
        self.adv_unitCellLineEdit.setObjectName("adv_unitCellLineEdit")
        self.gridLayout_4.addWidget(self.adv_unitCellLineEdit, 0, 1, 1, 1)
        self.elementsIncludedLabel = QtWidgets.QLabel(self.adv_searchtab)
        self.elementsIncludedLabel.setObjectName("elementsIncludedLabel")
        self.gridLayout_4.addWidget(self.elementsIncludedLabel, 2, 0, 1, 1)
        self.adv_elementsIncLineEdit = QtWidgets.QLineEdit(self.adv_searchtab)
        self.adv_elementsIncLineEdit.setText("")
        self.adv_elementsIncLineEdit.setObjectName("adv_elementsIncLineEdit")
        self.gridLayout_4.addWidget(self.adv_elementsIncLineEdit, 2, 1, 1, 1)
        self.unitCellLabel = QtWidgets.QLabel(self.adv_searchtab)
        self.unitCellLabel.setObjectName("unitCellLabel")
        self.gridLayout_4.addWidget(self.unitCellLabel, 0, 0, 1, 1)
        self.wR2Label_2 = QtWidgets.QLabel(self.adv_searchtab)
        self.wR2Label_2.setObjectName("wR2Label_2")
        self.gridLayout_4.addWidget(self.wR2Label_2, 3, 0, 1, 1)
        self.adv_textsearch = QtWidgets.QLineEdit(self.adv_searchtab)
        self.adv_textsearch.setObjectName("adv_textsearch")
        self.gridLayout_4.addWidget(self.adv_textsearch, 3, 1, 1, 1)
        self.onlyTheseElementsCheckBox = QtWidgets.QCheckBox(self.adv_searchtab)
        self.onlyTheseElementsCheckBox.setObjectName("onlyTheseElementsCheckBox")
        self.gridLayout_4.addWidget(self.onlyTheseElementsCheckBox, 2, 2, 1, 1)
        self.gridLayout_6.addLayout(self.gridLayout_4, 1, 0, 1, 1)
        spacerItem10 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        self.gridLayout_6.addItem(spacerItem10, 4, 0, 1, 3)
        self.line_3 = QtWidgets.QFrame(self.adv_searchtab)
        self.line_3.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_3.setObjectName("line_3")
        self.gridLayout_6.addWidget(self.line_3, 2, 0, 1, 1)
        self.line_6 = QtWidgets.QFrame(self.adv_searchtab)
        self.line_6.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_6.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_6.setObjectName("line_6")
        self.gridLayout_6.addWidget(self.line_6, 2, 2, 1, 1)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.adv_SearchPushButton = QtWidgets.QPushButton(self.adv_searchtab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.adv_SearchPushButton.sizePolicy().hasHeightForWidth())
        self.adv_SearchPushButton.setSizePolicy(sizePolicy)
        self.adv_SearchPushButton.setMinimumSize(QtCore.QSize(150, 0))
        self.adv_SearchPushButton.setObjectName("adv_SearchPushButton")
        self.horizontalLayout_2.addWidget(self.adv_SearchPushButton)
        self.adv_ClearSearchButton = QtWidgets.QPushButton(self.adv_searchtab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.adv_ClearSearchButton.sizePolicy().hasHeightForWidth())
        self.adv_ClearSearchButton.setSizePolicy(sizePolicy)
        self.adv_ClearSearchButton.setMinimumSize(QtCore.QSize(150, 0))
        self.adv_ClearSearchButton.setObjectName("adv_ClearSearchButton")
        self.horizontalLayout_2.addWidget(self.adv_ClearSearchButton)
        spacerItem11 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem11)
        self.gridLayout_6.addLayout(self.horizontalLayout_2, 5, 0, 1, 3)
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.adv_R1_search_line = QtWidgets.QLineEdit(self.adv_searchtab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.adv_R1_search_line.sizePolicy().hasHeightForWidth())
        self.adv_R1_search_line.setSizePolicy(sizePolicy)
        self.adv_R1_search_line.setObjectName("adv_R1_search_line")
        self.gridLayout_2.addWidget(self.adv_R1_search_line, 2, 1, 1, 1)
        self.adv_superlatticeCheckBox = QtWidgets.QCheckBox(self.adv_searchtab)
        self.adv_superlatticeCheckBox.setObjectName("adv_superlatticeCheckBox")
        self.gridLayout_2.addWidget(self.adv_superlatticeCheckBox, 0, 1, 1, 1)
        spacerItem12 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem12, 3, 4, 1, 1)
        self.wr2_search_label = QtWidgets.QLabel(self.adv_searchtab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.wr2_search_label.sizePolicy().hasHeightForWidth())
        self.wr2_search_label.setSizePolicy(sizePolicy)
        self.wr2_search_label.setObjectName("wr2_search_label")
        self.gridLayout_2.addWidget(self.wr2_search_label, 2, 0, 1, 1)
        spacerItem13 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem13, 1, 3, 1, 2)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.dateEdit1 = QtWidgets.QDateEdit(self.adv_searchtab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dateEdit1.sizePolicy().hasHeightForWidth())
        self.dateEdit1.setSizePolicy(sizePolicy)
        self.dateEdit1.setMinimumSize(QtCore.QSize(100, 0))
        self.dateEdit1.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.dateEdit1.setMinimumDate(QtCore.QDate(1900, 1, 1))
        self.dateEdit1.setCalendarPopup(True)
        self.dateEdit1.setDate(QtCore.QDate(1900, 1, 1))
        self.dateEdit1.setObjectName("dateEdit1")
        self.horizontalLayout_3.addWidget(self.dateEdit1)
        self.wR2Label_5 = QtWidgets.QLabel(self.adv_searchtab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.wR2Label_5.sizePolicy().hasHeightForWidth())
        self.wR2Label_5.setSizePolicy(sizePolicy)
        self.wR2Label_5.setMinimumSize(QtCore.QSize(0, 0))
        self.wR2Label_5.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.wR2Label_5.setAlignment(QtCore.Qt.AlignCenter)
        self.wR2Label_5.setObjectName("wR2Label_5")
        self.horizontalLayout_3.addWidget(self.wR2Label_5)
        self.dateEdit2 = QtWidgets.QDateEdit(self.adv_searchtab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dateEdit2.sizePolicy().hasHeightForWidth())
        self.dateEdit2.setSizePolicy(sizePolicy)
        self.dateEdit2.setMinimumSize(QtCore.QSize(100, 0))
        self.dateEdit2.setCorrectionMode(QtWidgets.QAbstractSpinBox.CorrectToNearestValue)
        self.dateEdit2.setMaximumDate(QtCore.QDate(7999, 12, 31))
        self.dateEdit2.setMinimumDate(QtCore.QDate(1752, 9, 14))
        self.dateEdit2.setCalendarPopup(True)
        self.dateEdit2.setDate(QtCore.QDate(7999, 12, 31))
        self.dateEdit2.setObjectName("dateEdit2")
        self.horizontalLayout_3.addWidget(self.dateEdit2)
        self.gridLayout_2.addLayout(self.horizontalLayout_3, 3, 1, 1, 3)
        spacerItem14 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem14, 2, 3, 1, 2)
        self.label_2 = QtWidgets.QLabel(self.adv_searchtab)
        self.label_2.setObjectName("label_2")
        self.gridLayout_2.addWidget(self.label_2, 2, 2, 1, 1)
        self.adv_moreResultscheckBox = QtWidgets.QCheckBox(self.adv_searchtab)
        self.adv_moreResultscheckBox.setObjectName("adv_moreResultscheckBox")
        self.gridLayout_2.addWidget(self.adv_moreResultscheckBox, 0, 0, 1, 1)
        self.spacegrouplabel = QtWidgets.QLabel(self.adv_searchtab)
        self.spacegrouplabel.setObjectName("spacegrouplabel")
        self.gridLayout_2.addWidget(self.spacegrouplabel, 1, 0, 1, 1)
        self.SpGrpComboBox = QtWidgets.QComboBox(self.adv_searchtab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.SpGrpComboBox.sizePolicy().hasHeightForWidth())
        self.SpGrpComboBox.setSizePolicy(sizePolicy)
        self.SpGrpComboBox.setObjectName("SpGrpComboBox")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.SpGrpComboBox.addItem("")
        self.gridLayout_2.addWidget(self.SpGrpComboBox, 1, 1, 1, 2)
        self.modifiedlabel = QtWidgets.QLabel(self.adv_searchtab)
        self.modifiedlabel.setObjectName("modifiedlabel")
        self.gridLayout_2.addWidget(self.modifiedlabel, 3, 0, 1, 1)
        self.CCDCNumLabel = QtWidgets.QLabel(self.adv_searchtab)
        self.CCDCNumLabel.setObjectName("CCDCNumLabel")
        self.gridLayout_2.addWidget(self.CCDCNumLabel, 4, 0, 1, 1)
        self.CCDCNumLineEdit = QtWidgets.QLineEdit(self.adv_searchtab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.CCDCNumLineEdit.sizePolicy().hasHeightForWidth())
        self.CCDCNumLineEdit.setSizePolicy(sizePolicy)
        self.CCDCNumLineEdit.setDragEnabled(True)
        self.CCDCNumLineEdit.setObjectName("CCDCNumLineEdit")
        self.gridLayout_2.addWidget(self.CCDCNumLineEdit, 4, 1, 1, 3)
        self.gridLayout_6.addLayout(self.gridLayout_2, 3, 0, 1, 3)
        self.horizontalLayout.addLayout(self.gridLayout_6)
        self.MaintabWidget.addTab(self.adv_searchtab, "")
        self.CCDCSearchTab = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.CCDCSearchTab.sizePolicy().hasHeightForWidth())
        self.CCDCSearchTab.setSizePolicy(sizePolicy)
        self.CCDCSearchTab.setObjectName("CCDCSearchTab")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.CCDCSearchTab)
        self.verticalLayout_5.setContentsMargins(10, -1, 10, 10)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setContentsMargins(-1, 0, -1, -1)
        self.verticalLayout_4.setSpacing(3)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.gridLayout_5 = QtWidgets.QGridLayout()
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.cellSearchCSDLineEdit = QtWidgets.QLineEdit(self.CCDCSearchTab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(20)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cellSearchCSDLineEdit.sizePolicy().hasHeightForWidth())
        self.cellSearchCSDLineEdit.setSizePolicy(sizePolicy)
        self.cellSearchCSDLineEdit.setObjectName("cellSearchCSDLineEdit")
        self.gridLayout_5.addWidget(self.cellSearchCSDLineEdit, 0, 1, 1, 1)
        self.lattCentComboBox = QtWidgets.QComboBox(self.CCDCSearchTab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(3)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lattCentComboBox.sizePolicy().hasHeightForWidth())
        self.lattCentComboBox.setSizePolicy(sizePolicy)
        self.lattCentComboBox.setObjectName("lattCentComboBox")
        self.lattCentComboBox.addItem("")
        self.lattCentComboBox.addItem("")
        self.lattCentComboBox.addItem("")
        self.lattCentComboBox.addItem("")
        self.lattCentComboBox.addItem("")
        self.lattCentComboBox.addItem("")
        self.lattCentComboBox.addItem("")
        self.gridLayout_5.addWidget(self.lattCentComboBox, 0, 3, 1, 1)
        self.CSDpushButton = QtWidgets.QPushButton(self.CCDCSearchTab)
        self.CSDpushButton.setMinimumSize(QtCore.QSize(120, 0))
        self.CSDpushButton.setObjectName("CSDpushButton")
        self.gridLayout_5.addWidget(self.CSDpushButton, 0, 4, 1, 1)
        self.latticeCenteringLabel = QtWidgets.QLabel(self.CCDCSearchTab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(4)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.latticeCenteringLabel.sizePolicy().hasHeightForWidth())
        self.latticeCenteringLabel.setSizePolicy(sizePolicy)
        self.latticeCenteringLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.latticeCenteringLabel.setObjectName("latticeCenteringLabel")
        self.gridLayout_5.addWidget(self.latticeCenteringLabel, 0, 2, 1, 1)
        self.cellSearchLabelCSD = QtWidgets.QLabel(self.CCDCSearchTab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cellSearchLabelCSD.sizePolicy().hasHeightForWidth())
        self.cellSearchLabelCSD.setSizePolicy(sizePolicy)
        self.cellSearchLabelCSD.setObjectName("cellSearchLabelCSD")
        self.gridLayout_5.addWidget(self.cellSearchLabelCSD, 0, 0, 1, 1)
        self.gridLayout_5.setColumnStretch(0, 4)
        self.verticalLayout_4.addLayout(self.gridLayout_5)
        self.CSDtreeWidget = QtWidgets.QTreeWidget(self.CCDCSearchTab)
        self.CSDtreeWidget.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAsNeeded)
        self.CSDtreeWidget.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAsNeeded)
        self.CSDtreeWidget.setUniformRowHeights(False)
        self.CSDtreeWidget.setObjectName("CSDtreeWidget")
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.CSDtreeWidget.headerItem().setFont(4, font)
        self.CSDtreeWidget.header().setCascadingSectionResizes(False)
        self.CSDtreeWidget.header().setDefaultSectionSize(60)
        self.CSDtreeWidget.header().setHighlightSections(False)
        self.CSDtreeWidget.header().setMinimumSectionSize(20)
        self.CSDtreeWidget.header().setSortIndicatorShown(False)
        self.CSDtreeWidget.header().setStretchLastSection(True)
        self.verticalLayout_4.addWidget(self.CSDtreeWidget)
        self.ccdc_exe_HorizontalLayout = QtWidgets.QHBoxLayout()
        self.ccdc_exe_HorizontalLayout.setContentsMargins(-1, 14, -1, -1)
        self.ccdc_exe_HorizontalLayout.setObjectName("ccdc_exe_HorizontalLayout")
        self.cellcheckExeLineEdit = QtWidgets.QLineEdit(self.CCDCSearchTab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(2)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cellcheckExeLineEdit.sizePolicy().hasHeightForWidth())
        self.cellcheckExeLineEdit.setSizePolicy(sizePolicy)
        self.cellcheckExeLineEdit.setReadOnly(True)
        self.cellcheckExeLineEdit.setObjectName("cellcheckExeLineEdit")
        self.ccdc_exe_HorizontalLayout.addWidget(self.cellcheckExeLineEdit)
        self.cellcheckExePushButton = QtWidgets.QPushButton(self.CCDCSearchTab)
        self.cellcheckExePushButton.setObjectName("cellcheckExePushButton")
        self.ccdc_exe_HorizontalLayout.addWidget(self.cellcheckExePushButton)
        self.cellcheckLabel = QtWidgets.QLabel(self.CCDCSearchTab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cellcheckLabel.sizePolicy().hasHeightForWidth())
        self.cellcheckLabel.setSizePolicy(sizePolicy)
        self.cellcheckLabel.setOpenExternalLinks(True)
        self.cellcheckLabel.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByKeyboard|QtCore.Qt.LinksAccessibleByMouse)
        self.cellcheckLabel.setObjectName("cellcheckLabel")
        self.ccdc_exe_HorizontalLayout.addWidget(self.cellcheckLabel)
        self.verticalLayout_4.addLayout(self.ccdc_exe_HorizontalLayout)
        self.verticalLayout_5.addLayout(self.verticalLayout_4)
        self.MaintabWidget.addTab(self.CCDCSearchTab, "")
        self.verticalLayout_6.addWidget(self.MaintabWidget)
        self.verticalLayout_9 = QtWidgets.QVBoxLayout()
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.DatabaseNameDisplayLabel = QtWidgets.QLabel(self.centralwidget)
        self.DatabaseNameDisplayLabel.setText("")
        self.DatabaseNameDisplayLabel.setObjectName("DatabaseNameDisplayLabel")
        self.verticalLayout_9.addWidget(self.DatabaseNameDisplayLabel)
        self.verticalLayout_6.addLayout(self.verticalLayout_9)
        self.horizontalLayout_5.addLayout(self.verticalLayout_6)
        stdbMainwindow.setCentralWidget(self.centralwidget)
        self.statusbar = QtWidgets.QStatusBar(stdbMainwindow)
        self.statusbar.setObjectName("statusbar")
        stdbMainwindow.setStatusBar(self.statusbar)
        self.actionExit = QtWidgets.QAction(stdbMainwindow)
        self.actionExit.setObjectName("actionExit")
        self.actionUser_manual = QtWidgets.QAction(stdbMainwindow)
        self.actionUser_manual.setObjectName("actionUser_manual")
        self.actionImport_file = QtWidgets.QAction(stdbMainwindow)
        self.actionImport_file.setObjectName("actionImport_file")
        self.actionImport_directory = QtWidgets.QAction(stdbMainwindow)
        self.actionImport_directory.setObjectName("actionImport_directory")
        self.actionSave_Database = QtWidgets.QAction(stdbMainwindow)
        self.actionSave_Database.setObjectName("actionSave_Database")
        self.actionAdvanced_Search = QtWidgets.QAction(stdbMainwindow)
        self.actionAdvanced_Search.setObjectName("actionAdvanced_Search")
        self.actionAbout_StructureDB = QtWidgets.QAction(stdbMainwindow)
        self.actionAbout_StructureDB.setObjectName("actionAbout_StructureDB")
        self.actionClose_Database = QtWidgets.QAction(stdbMainwindow)
        self.actionClose_Database.setObjectName("actionClose_Database")
        self.actionCopy_Unit_Cell = QtWidgets.QAction(stdbMainwindow)
        self.actionCopy_Unit_Cell.setObjectName("actionCopy_Unit_Cell")
        self.actionGo_to_All_CIF_Tab = QtWidgets.QAction(stdbMainwindow)
        self.actionGo_to_All_CIF_Tab.setObjectName("actionGo_to_All_CIF_Tab")

        self.retranslateUi(stdbMainwindow)
        self.MaintabWidget.setCurrentIndex(0)
        self.actionExit.triggered.connect(stdbMainwindow.close) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(stdbMainwindow)
        stdbMainwindow.setTabOrder(self.importDirButton, self.importDatabaseButton)
        stdbMainwindow.setTabOrder(self.importDatabaseButton, self.closeDatabaseButton)
        stdbMainwindow.setTabOrder(self.closeDatabaseButton, self.cifList_tableView)
        stdbMainwindow.setTabOrder(self.cifList_tableView, self.searchCellLineEDit)
        stdbMainwindow.setTabOrder(self.searchCellLineEDit, self.moreResultsCheckBox)
        stdbMainwindow.setTabOrder(self.moreResultsCheckBox, self.txtSearchEdit)
        stdbMainwindow.setTabOrder(self.txtSearchEdit, self.SpaceGroupLineEdit)
        stdbMainwindow.setTabOrder(self.SpaceGroupLineEdit, self.zLineEdit)
        stdbMainwindow.setTabOrder(self.zLineEdit, self.temperatureLineEdit)
        stdbMainwindow.setTabOrder(self.temperatureLineEdit, self.wR2LineEdit)
        stdbMainwindow.setTabOrder(self.wR2LineEdit, self.r1LineEdit)
        stdbMainwindow.setTabOrder(self.r1LineEdit, self.goofLineEdit)
        stdbMainwindow.setTabOrder(self.goofLineEdit, self.maxShiftLineEdit)
        stdbMainwindow.setTabOrder(self.maxShiftLineEdit, self.peakLineEdit)
        stdbMainwindow.setTabOrder(self.peakLineEdit, self.rintLineEdit)
        stdbMainwindow.setTabOrder(self.rintLineEdit, self.rsigmaLineEdit)
        stdbMainwindow.setTabOrder(self.rsigmaLineEdit, self.numParametersLineEdit)
        stdbMainwindow.setTabOrder(self.numParametersLineEdit, self.dataReflnsLineEdit)
        stdbMainwindow.setTabOrder(self.dataReflnsLineEdit, self.numRestraintsLineEdit)
        stdbMainwindow.setTabOrder(self.numRestraintsLineEdit, self.thetaMaxLineEdit)
        stdbMainwindow.setTabOrder(self.thetaMaxLineEdit, self.thetaFullLineEdit)
        stdbMainwindow.setTabOrder(self.thetaFullLineEdit, self.dLineEdit)
        stdbMainwindow.setTabOrder(self.dLineEdit, self.completeLineEdit)
        stdbMainwindow.setTabOrder(self.completeLineEdit, self.cCDCNumberLineEdit)
        stdbMainwindow.setTabOrder(self.cCDCNumberLineEdit, self.allCifTreeWidget)
        stdbMainwindow.setTabOrder(self.allCifTreeWidget, self.adv_unitCellLineEdit)
        stdbMainwindow.setTabOrder(self.adv_unitCellLineEdit, self.adv_elementsIncLineEdit)
        stdbMainwindow.setTabOrder(self.adv_elementsIncLineEdit, self.adv_textsearch)
        stdbMainwindow.setTabOrder(self.adv_textsearch, self.adv_elementsExclLineEdit)
        stdbMainwindow.setTabOrder(self.adv_elementsExclLineEdit, self.adv_textsearch_excl)

    def retranslateUi(self, stdbMainwindow):
        _translate = QtCore.QCoreApplication.translate
        stdbMainwindow.setWindowTitle(_translate("stdbMainwindow", "StructureFinder"))
        self.importDirButton.setToolTip(_translate("stdbMainwindow", "<html><head/><body><p><span style=\" font-weight:400;\">This will import all .cif files that could be found below the given directory.</span></p></body></html>"))
        self.importDirButton.setText(_translate("stdbMainwindow", "Import Directory"))
        self.appendDirButton.setToolTip(_translate("stdbMainwindow", "<html><head/><body><p><span style=\" font-weight:400;\">This will import all .cif files that could be found below the given directory.</span></p></body></html>"))
        self.appendDirButton.setText(_translate("stdbMainwindow", "Append Directory"))
        self.add_cif.setToolTip(_translate("stdbMainwindow", "<html><head/><body><p>This option will import .cif files (crystallograpghic information file) into the database.</p></body></html>"))
        self.add_cif.setText(_translate("stdbMainwindow", "import .cif files"))
        self.add_res.setToolTip(_translate("stdbMainwindow", "<html><head/><body><p>This option will import .res files from SHELXL into the database.</p></body></html>"))
        self.add_res.setText(_translate("stdbMainwindow", "import .res files"))
        self.importDatabaseButton.setText(_translate("stdbMainwindow", "Open Database File"))
        self.saveDatabaseButton.setText(_translate("stdbMainwindow", "Save Database"))
        self.appendDatabasePushButton.setText(_translate("stdbMainwindow", "Append a Database"))
        self.p4pCellButton.setText(_translate("stdbMainwindow", "Import Cell from File"))
        self.closeDatabaseButton.setText(_translate("stdbMainwindow", "Close Database"))
        self.SpaceGrouplabel.setText(_translate("stdbMainwindow", "Space Group"))
        self.zLabel.setText(_translate("stdbMainwindow", "<html><head/><body><p>Z</p></body></html>"))
        self.temperatureLabel.setText(_translate("stdbMainwindow", "Temperature [K]"))
        self.wR2Label.setText(_translate("stdbMainwindow", "<html><head/><body><p><span style=\" font-style:italic;\">wR</span><span style=\" vertical-align:sub;\">2</span><span style=\" font-style:italic; vertical-align:sub;\"/></p></body></html>"))
        self.r1Label.setText(_translate("stdbMainwindow", "<html><head/><body><p><span style=\" font-style:italic;\">R</span><span style=\" vertical-align:sub;\">1</span></p></body></html>"))
        self.goofLabel.setText(_translate("stdbMainwindow", "Goof"))
        self.maxShiftLabel.setText(_translate("stdbMainwindow", "Max Shift/esd"))
        self.peakLabel.setText(_translate("stdbMainwindow", "<html><head/><body><p>Peak/Hole [eÅ<span style=\" vertical-align:super;\">-3</span>]</p></body></html>"))
        self.rintLabel.setText(_translate("stdbMainwindow", "<html><head/><body><p><span style=\" font-style:italic;\">R</span><span style=\" vertical-align:sub;\">int</span></p></body></html>"))
        self.rsigmaLabel.setText(_translate("stdbMainwindow", "<html><head/><body><p><span style=\" font-style:italic;\">R</span><span style=\" vertical-align:sub;\">σ</span></p></body></html>"))
        self.CellLabel.setText(_translate("stdbMainwindow", "Unit Cell:"))
        self.label.setText(_translate("stdbMainwindow", "Sum Formula:"))
        self.reflTotalLabel.setText(_translate("stdbMainwindow", "Measured Refl."))
        self.uniqReflLabel.setText(_translate("stdbMainwindow", "Independent Refl."))
        self.refl2sigmaLabel.setText(_translate("stdbMainwindow", "<html><head/><body><p>Data with [<span style=\" font-style:italic;\">I</span>&gt;2σ(<span style=\" font-style:italic;\">I</span>)]</p></body></html>"))
        self.wavelengthLabel.setText(_translate("stdbMainwindow", "Wavelength [Å]"))
        self.ExportAsCIFpushButton.setText(_translate("stdbMainwindow", "Export as CIF"))
        self.molGroupBox.setTitle(_translate("stdbMainwindow", "Asymmetric Unit"))
        self.growCheckBox.setText(_translate("stdbMainwindow", "Grow Structure"))
        self.labelsCheckBox.setText(_translate("stdbMainwindow", "Show Labels"))
        self.numParametersLabel.setText(_translate("stdbMainwindow", "Parameters"))
        self.dataReflnsLabel.setText(_translate("stdbMainwindow", "data/param"))
        self.numRestraintsLabel.setText(_translate("stdbMainwindow", "Restraints"))
        self.thetaMaxLabel.setText(_translate("stdbMainwindow", "θ(max) [°]"))
        self.thetaFullLabel.setText(_translate("stdbMainwindow", "θ(full) [°]"))
        self.dLabel.setText(_translate("stdbMainwindow", "<html><head/><body><p>d [Å]</p></body></html>"))
        self.completeLabel.setText(_translate("stdbMainwindow", "complete [%]"))
        self.cCDCNumberLabel.setText(_translate("stdbMainwindow", "CCDC Num."))
        self.lastModifiedLabel.setText(_translate("stdbMainwindow", "Last Modified"))
        self.flackXLabel.setText(_translate("stdbMainwindow", "Flack x"))
        self.searchLabel.setText(_translate("stdbMainwindow", "Cell Search:"))
        self.searchCellLineEDit.setToolTip(_translate("stdbMainwindow", "<html><head/><body><p>Insert unit cell as space separated <br/>numbers: <span style=\" font-style:italic;\">a b c α β γ</span></p></body></html>"))
        self.searchCellLineEDit.setPlaceholderText(_translate("stdbMainwindow", "a b c alpha beta gamma"))
        self.moreResultsCheckBox.setToolTip(_translate("stdbMainwindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'.SF NS Text\'; font-size:13pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; background-color:#ffffff;\"><span style=\" font-family:\'Menlo\'; font-weight:600; color:#000000;\">regular</span><span style=\" font-family:\'Menlo\'; color:#000000;\"><br />volume: ±3.0%, length: 0.06 Å, <br />angle: 1.0°<br /><br /></span><span style=\" font-family:\'Menlo\'; font-weight:600; color:#000000;\">more results option</span><span style=\" font-family:\'Menlo\'; color:#000000;\"><br />volume: ±9.0%, length: 0.2 Å, <br />angle: 2.0°</span></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p></body></html>"))
        self.moreResultsCheckBox.setText(_translate("stdbMainwindow", "More Results"))
        self.sublattCheckbox.setToolTip(_translate("stdbMainwindow", "<html><head/><body><pre style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; background-color:#ffffff;\"><span style=\" font-family:\'Menlo\'; color:#000000; background-color:#ffffff;\">Find also unit cells of 1, 2, 3, 4, 6, 8, 10 times the volume.</span></pre></body></html>"))
        self.sublattCheckbox.setText(_translate("stdbMainwindow", "Find Superlattices"))
        self.txtSearchLabel.setText(_translate("stdbMainwindow", "Search text:"))
        self.txtSearchEdit.setPlaceholderText(_translate("stdbMainwindow", "text in name, path or .res file"))
        self.MaintabWidget.setTabText(self.MaintabWidget.indexOf(self.maintab), _translate("stdbMainwindow", "Structures"))
        self.allCifTreeWidget.headerItem().setText(0, _translate("stdbMainwindow", "Keys"))
        self.allCifTreeWidget.headerItem().setText(1, _translate("stdbMainwindow", "Values"))
        self.MaintabWidget.setTabText(self.MaintabWidget.indexOf(self.allEntrysTab), _translate("stdbMainwindow", "All cif values"))
        self.SHELXplainTextEdit.setPlainText(_translate("stdbMainwindow", "Select a cif file first."))
        self.MaintabWidget.setTabText(self.MaintabWidget.indexOf(self.SHELXtab), _translate("stdbMainwindow", "SHELX res file"))
        self.NotContainsLabel.setText(_translate("stdbMainwindow", "Should not contain"))
        self.adv_elementsExclLineEdit.setPlaceholderText(_translate("stdbMainwindow", "e.g. Pt Au Al"))
        self.elementsExcludedLabel_2.setText(_translate("stdbMainwindow", "Elements"))
        self.wR2Label_3.setText(_translate("stdbMainwindow", "Any Text"))
        self.adv_textsearch_excl.setPlaceholderText(_translate("stdbMainwindow", "e.g. test"))
        self.containsLabel.setText(_translate("stdbMainwindow", "Should contain"))
        self.adv_unitCellLineEdit.setPlaceholderText(_translate("stdbMainwindow", "a b c alpha beta gamma"))
        self.elementsIncludedLabel.setText(_translate("stdbMainwindow", "Elements"))
        self.adv_elementsIncLineEdit.setPlaceholderText(_translate("stdbMainwindow", "e.g. C H O"))
        self.unitCellLabel.setText(_translate("stdbMainwindow", "Unit Cell"))
        self.wR2Label_2.setText(_translate("stdbMainwindow", "Any Text"))
        self.adv_textsearch.setPlaceholderText(_translate("stdbMainwindow", "e.g. TWIN"))
        self.onlyTheseElementsCheckBox.setText(_translate("stdbMainwindow", "Only these"))
        self.adv_SearchPushButton.setText(_translate("stdbMainwindow", "Search"))
        self.adv_ClearSearchButton.setText(_translate("stdbMainwindow", "Clear Search"))
        self.adv_superlatticeCheckBox.setText(_translate("stdbMainwindow", "Sub- or Superlattice"))
        self.wr2_search_label.setText(_translate("stdbMainwindow", "<html><head/><body><p><span style=\" font-style:italic;\">R</span><span style=\" vertical-align:sub;\">1</span> less than</p></body></html>"))
        self.dateEdit1.setDisplayFormat(_translate("stdbMainwindow", "yyyy-MM-dd"))
        self.wR2Label_5.setText(_translate("stdbMainwindow", "and"))
        self.dateEdit2.setDisplayFormat(_translate("stdbMainwindow", "yyyy-MM-dd"))
        self.label_2.setText(_translate("stdbMainwindow", "%"))
        self.adv_moreResultscheckBox.setText(_translate("stdbMainwindow", "More Results"))
        self.spacegrouplabel.setText(_translate("stdbMainwindow", "Space Group"))
        self.SpGrpComboBox.setToolTip(_translate("stdbMainwindow", "<html><head/><body><pre style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; background-color:#ffffff;\"><span style=\" font-family:\'Menlo\'; color:#000000; background-color:#ffffff;\">Be aware that not every cif file before SHELXL-2013 has a space group number. These will not be found.</span></pre></body></html>"))
        self.SpGrpComboBox.setItemText(0, _translate("stdbMainwindow", "None"))
        self.SpGrpComboBox.setItemText(1, _translate("stdbMainwindow", "1 (P1)"))
        self.SpGrpComboBox.setItemText(2, _translate("stdbMainwindow", "2 (P-1)"))
        self.SpGrpComboBox.setItemText(3, _translate("stdbMainwindow", "3 (P 2)"))
        self.SpGrpComboBox.setItemText(4, _translate("stdbMainwindow", "4 (P 21)"))
        self.SpGrpComboBox.setItemText(5, _translate("stdbMainwindow", "5 (C 2)"))
        self.SpGrpComboBox.setItemText(6, _translate("stdbMainwindow", "6 (P m)"))
        self.SpGrpComboBox.setItemText(7, _translate("stdbMainwindow", "7 (P c)"))
        self.SpGrpComboBox.setItemText(8, _translate("stdbMainwindow", "8 (C m)"))
        self.SpGrpComboBox.setItemText(9, _translate("stdbMainwindow", "9 (C c)"))
        self.SpGrpComboBox.setItemText(10, _translate("stdbMainwindow", "10 (P 2/m)"))
        self.SpGrpComboBox.setItemText(11, _translate("stdbMainwindow", "11 (P 21/m)"))
        self.SpGrpComboBox.setItemText(12, _translate("stdbMainwindow", "12 (C 2/m)"))
        self.SpGrpComboBox.setItemText(13, _translate("stdbMainwindow", "13 (P 2/c)"))
        self.SpGrpComboBox.setItemText(14, _translate("stdbMainwindow", "14 (P 21/c)"))
        self.SpGrpComboBox.setItemText(15, _translate("stdbMainwindow", "15 (C 2/c)"))
        self.SpGrpComboBox.setItemText(16, _translate("stdbMainwindow", "16 (P 2 2 2)"))
        self.SpGrpComboBox.setItemText(17, _translate("stdbMainwindow", "17 (P 2 2 21)"))
        self.SpGrpComboBox.setItemText(18, _translate("stdbMainwindow", "18 (P 21 21 2)"))
        self.SpGrpComboBox.setItemText(19, _translate("stdbMainwindow", "19 (P 21 21 21)"))
        self.SpGrpComboBox.setItemText(20, _translate("stdbMainwindow", "20 (C 2 2 21)"))
        self.SpGrpComboBox.setItemText(21, _translate("stdbMainwindow", "21 (C 2 2 2)"))
        self.SpGrpComboBox.setItemText(22, _translate("stdbMainwindow", "22 (F 2 2 2)"))
        self.SpGrpComboBox.setItemText(23, _translate("stdbMainwindow", "23 (I 2 2 2) "))
        self.SpGrpComboBox.setItemText(24, _translate("stdbMainwindow", "24 (I 21 21 21) "))
        self.SpGrpComboBox.setItemText(25, _translate("stdbMainwindow", "25 (P m m 2) "))
        self.SpGrpComboBox.setItemText(26, _translate("stdbMainwindow", "26 (P m c 21) "))
        self.SpGrpComboBox.setItemText(27, _translate("stdbMainwindow", "27 (P c c 2) "))
        self.SpGrpComboBox.setItemText(28, _translate("stdbMainwindow", "28 (P m a 2)"))
        self.SpGrpComboBox.setItemText(29, _translate("stdbMainwindow", "29 (P c a 21)"))
        self.SpGrpComboBox.setItemText(30, _translate("stdbMainwindow", "30 (P n c 2)"))
        self.SpGrpComboBox.setItemText(31, _translate("stdbMainwindow", "31 (P m n 21)"))
        self.SpGrpComboBox.setItemText(32, _translate("stdbMainwindow", "32 (P b a 2)"))
        self.SpGrpComboBox.setItemText(33, _translate("stdbMainwindow", "33 (P n a 21)"))
        self.SpGrpComboBox.setItemText(34, _translate("stdbMainwindow", "34 (P n n 2)"))
        self.SpGrpComboBox.setItemText(35, _translate("stdbMainwindow", "35 (C m m 2)"))
        self.SpGrpComboBox.setItemText(36, _translate("stdbMainwindow", "36 (C m c 21)"))
        self.SpGrpComboBox.setItemText(37, _translate("stdbMainwindow", "37 (C c c 2)"))
        self.SpGrpComboBox.setItemText(38, _translate("stdbMainwindow", "38 (A m m 2)"))
        self.SpGrpComboBox.setItemText(39, _translate("stdbMainwindow", "39 (A e m 2)"))
        self.SpGrpComboBox.setItemText(40, _translate("stdbMainwindow", "40 (A m a 2)"))
        self.SpGrpComboBox.setItemText(41, _translate("stdbMainwindow", "41 (A e a 2)"))
        self.SpGrpComboBox.setItemText(42, _translate("stdbMainwindow", "42 (F m m 2)"))
        self.SpGrpComboBox.setItemText(43, _translate("stdbMainwindow", "43 (F d d 2)"))
        self.SpGrpComboBox.setItemText(44, _translate("stdbMainwindow", "44 (I m m 2)"))
        self.SpGrpComboBox.setItemText(45, _translate("stdbMainwindow", "45 (I b a 2)"))
        self.SpGrpComboBox.setItemText(46, _translate("stdbMainwindow", "46 (I m a 2)"))
        self.SpGrpComboBox.setItemText(47, _translate("stdbMainwindow", "47 (P m m m)"))
        self.SpGrpComboBox.setItemText(48, _translate("stdbMainwindow", "48 (P n n n)"))
        self.SpGrpComboBox.setItemText(49, _translate("stdbMainwindow", "49 (P c c m)"))
        self.SpGrpComboBox.setItemText(50, _translate("stdbMainwindow", "50 (P b a n)"))
        self.SpGrpComboBox.setItemText(51, _translate("stdbMainwindow", "51 (P m m a)"))
        self.SpGrpComboBox.setItemText(52, _translate("stdbMainwindow", "52 (P n n a)"))
        self.SpGrpComboBox.setItemText(53, _translate("stdbMainwindow", "53 (P m n a)"))
        self.SpGrpComboBox.setItemText(54, _translate("stdbMainwindow", "54 (P c c a)"))
        self.SpGrpComboBox.setItemText(55, _translate("stdbMainwindow", "55 (P b a m)"))
        self.SpGrpComboBox.setItemText(56, _translate("stdbMainwindow", "56 (P c c n)"))
        self.SpGrpComboBox.setItemText(57, _translate("stdbMainwindow", "57 (P b c m)"))
        self.SpGrpComboBox.setItemText(58, _translate("stdbMainwindow", "58 (P n n m)"))
        self.SpGrpComboBox.setItemText(59, _translate("stdbMainwindow", "59 (P m m n)"))
        self.SpGrpComboBox.setItemText(60, _translate("stdbMainwindow", "60 (P b c n)"))
        self.SpGrpComboBox.setItemText(61, _translate("stdbMainwindow", "61 (P b c a)"))
        self.SpGrpComboBox.setItemText(62, _translate("stdbMainwindow", "62 (P n m a)"))
        self.SpGrpComboBox.setItemText(63, _translate("stdbMainwindow", "63 (C m c m)"))
        self.SpGrpComboBox.setItemText(64, _translate("stdbMainwindow", "64 (C m c e)"))
        self.SpGrpComboBox.setItemText(65, _translate("stdbMainwindow", "65 (C m m m)"))
        self.SpGrpComboBox.setItemText(66, _translate("stdbMainwindow", "66 (C c c m)"))
        self.SpGrpComboBox.setItemText(67, _translate("stdbMainwindow", "67 (C m m e)"))
        self.SpGrpComboBox.setItemText(68, _translate("stdbMainwindow", "68 (C c c e)"))
        self.SpGrpComboBox.setItemText(69, _translate("stdbMainwindow", "69 (F m m m)"))
        self.SpGrpComboBox.setItemText(70, _translate("stdbMainwindow", "70 (F d d d)"))
        self.SpGrpComboBox.setItemText(71, _translate("stdbMainwindow", "71 (I m m m)"))
        self.SpGrpComboBox.setItemText(72, _translate("stdbMainwindow", "72 (I b a m)"))
        self.SpGrpComboBox.setItemText(73, _translate("stdbMainwindow", "73 (I b c a)"))
        self.SpGrpComboBox.setItemText(74, _translate("stdbMainwindow", "74 (I m m a)"))
        self.SpGrpComboBox.setItemText(75, _translate("stdbMainwindow", "75 (P 4)"))
        self.SpGrpComboBox.setItemText(76, _translate("stdbMainwindow", "76 (P 41)"))
        self.SpGrpComboBox.setItemText(77, _translate("stdbMainwindow", "77 (P 42)"))
        self.SpGrpComboBox.setItemText(78, _translate("stdbMainwindow", "78 (P 43)"))
        self.SpGrpComboBox.setItemText(79, _translate("stdbMainwindow", "79 (I 4)"))
        self.SpGrpComboBox.setItemText(80, _translate("stdbMainwindow", "80 (I 41)"))
        self.SpGrpComboBox.setItemText(81, _translate("stdbMainwindow", "81 (P -4)"))
        self.SpGrpComboBox.setItemText(82, _translate("stdbMainwindow", "82 (I -4)"))
        self.SpGrpComboBox.setItemText(83, _translate("stdbMainwindow", "83 (P 4/m)"))
        self.SpGrpComboBox.setItemText(84, _translate("stdbMainwindow", "84 (P 42/m)"))
        self.SpGrpComboBox.setItemText(85, _translate("stdbMainwindow", "85 (P 4/n)"))
        self.SpGrpComboBox.setItemText(86, _translate("stdbMainwindow", "86 (P 42/n)"))
        self.SpGrpComboBox.setItemText(87, _translate("stdbMainwindow", "87 (I 4/m)"))
        self.SpGrpComboBox.setItemText(88, _translate("stdbMainwindow", "88 (I 41/a)"))
        self.SpGrpComboBox.setItemText(89, _translate("stdbMainwindow", "89 (P 4 2 2)"))
        self.SpGrpComboBox.setItemText(90, _translate("stdbMainwindow", "90 (P 4 21 2)"))
        self.SpGrpComboBox.setItemText(91, _translate("stdbMainwindow", "91 (P 41 2 2)"))
        self.SpGrpComboBox.setItemText(92, _translate("stdbMainwindow", "92 (P 41 21 2)"))
        self.SpGrpComboBox.setItemText(93, _translate("stdbMainwindow", "93 (P 42 2 2)"))
        self.SpGrpComboBox.setItemText(94, _translate("stdbMainwindow", "94 (P 42 21 2)"))
        self.SpGrpComboBox.setItemText(95, _translate("stdbMainwindow", "95 (P 43 2 2)"))
        self.SpGrpComboBox.setItemText(96, _translate("stdbMainwindow", "96 (P 43 21 2)"))
        self.SpGrpComboBox.setItemText(97, _translate("stdbMainwindow", "97 (I 4 2 2)"))
        self.SpGrpComboBox.setItemText(98, _translate("stdbMainwindow", "98 (I 41 2 2)"))
        self.SpGrpComboBox.setItemText(99, _translate("stdbMainwindow", "99 (P 4 m m)"))
        self.SpGrpComboBox.setItemText(100, _translate("stdbMainwindow", "100 (P 4 b m)"))
        self.SpGrpComboBox.setItemText(101, _translate("stdbMainwindow", "101 (P 42 c m)"))
        self.SpGrpComboBox.setItemText(102, _translate("stdbMainwindow", "102 (P 42 n m)"))
        self.SpGrpComboBox.setItemText(103, _translate("stdbMainwindow", "103 (P 4 c c)"))
        self.SpGrpComboBox.setItemText(104, _translate("stdbMainwindow", "104 (P 4 n c)"))
        self.SpGrpComboBox.setItemText(105, _translate("stdbMainwindow", "105 (P 42 m c)"))
        self.SpGrpComboBox.setItemText(106, _translate("stdbMainwindow", "106 (P 42 b c)"))
        self.SpGrpComboBox.setItemText(107, _translate("stdbMainwindow", "107 (I 4 m m)"))
        self.SpGrpComboBox.setItemText(108, _translate("stdbMainwindow", "108 (I 4 c m)"))
        self.SpGrpComboBox.setItemText(109, _translate("stdbMainwindow", "109 (I 41 m d)"))
        self.SpGrpComboBox.setItemText(110, _translate("stdbMainwindow", "110 (I 41 c d)"))
        self.SpGrpComboBox.setItemText(111, _translate("stdbMainwindow", "111 (P -4 2 m)"))
        self.SpGrpComboBox.setItemText(112, _translate("stdbMainwindow", "112 (P -4 2 c)"))
        self.SpGrpComboBox.setItemText(113, _translate("stdbMainwindow", "113 (P -4 21 m)"))
        self.SpGrpComboBox.setItemText(114, _translate("stdbMainwindow", "114 (P -4 21 c)"))
        self.SpGrpComboBox.setItemText(115, _translate("stdbMainwindow", "115 (P -4 m 2)"))
        self.SpGrpComboBox.setItemText(116, _translate("stdbMainwindow", "116 (P -4 c 2)"))
        self.SpGrpComboBox.setItemText(117, _translate("stdbMainwindow", "117 (P -4 b 2)"))
        self.SpGrpComboBox.setItemText(118, _translate("stdbMainwindow", "118 (P -4 n 2)"))
        self.SpGrpComboBox.setItemText(119, _translate("stdbMainwindow", "119 (I -4 m 2)"))
        self.SpGrpComboBox.setItemText(120, _translate("stdbMainwindow", "120 (I -4 c 2)"))
        self.SpGrpComboBox.setItemText(121, _translate("stdbMainwindow", "121 (I -4 2 m)"))
        self.SpGrpComboBox.setItemText(122, _translate("stdbMainwindow", "122 (I -4 2 d)"))
        self.SpGrpComboBox.setItemText(123, _translate("stdbMainwindow", "123 (P 4/m m m)"))
        self.SpGrpComboBox.setItemText(124, _translate("stdbMainwindow", "124 (P 4/m c c)"))
        self.SpGrpComboBox.setItemText(125, _translate("stdbMainwindow", "125 (P 4/n b m)"))
        self.SpGrpComboBox.setItemText(126, _translate("stdbMainwindow", "126 (P 4/n n c)"))
        self.SpGrpComboBox.setItemText(127, _translate("stdbMainwindow", "127 (P 4/m b m)"))
        self.SpGrpComboBox.setItemText(128, _translate("stdbMainwindow", "128 (P 4/m n c)"))
        self.SpGrpComboBox.setItemText(129, _translate("stdbMainwindow", "129 (P 4/n m m)"))
        self.SpGrpComboBox.setItemText(130, _translate("stdbMainwindow", "130 (P 4/n c c)"))
        self.SpGrpComboBox.setItemText(131, _translate("stdbMainwindow", "131 (P 42/m m c)"))
        self.SpGrpComboBox.setItemText(132, _translate("stdbMainwindow", "132 (P 42/m c m)"))
        self.SpGrpComboBox.setItemText(133, _translate("stdbMainwindow", "133 (P 42/n b c)"))
        self.SpGrpComboBox.setItemText(134, _translate("stdbMainwindow", "134 (P 42/n n m)"))
        self.SpGrpComboBox.setItemText(135, _translate("stdbMainwindow", "135 (P 42/m b c)"))
        self.SpGrpComboBox.setItemText(136, _translate("stdbMainwindow", "136 (P 42/m n m)"))
        self.SpGrpComboBox.setItemText(137, _translate("stdbMainwindow", "137 (P 42/n m c)"))
        self.SpGrpComboBox.setItemText(138, _translate("stdbMainwindow", "138 (P 42/n c m)"))
        self.SpGrpComboBox.setItemText(139, _translate("stdbMainwindow", "139 (I 4/m m m)"))
        self.SpGrpComboBox.setItemText(140, _translate("stdbMainwindow", "140 (I 4/m c m)"))
        self.SpGrpComboBox.setItemText(141, _translate("stdbMainwindow", "141 (I 41/a m d)"))
        self.SpGrpComboBox.setItemText(142, _translate("stdbMainwindow", "142 (I 41/a c d)"))
        self.SpGrpComboBox.setItemText(143, _translate("stdbMainwindow", "143 (P 3)"))
        self.SpGrpComboBox.setItemText(144, _translate("stdbMainwindow", "144 (P 31)"))
        self.SpGrpComboBox.setItemText(145, _translate("stdbMainwindow", "145 (P 32)"))
        self.SpGrpComboBox.setItemText(146, _translate("stdbMainwindow", "146 (R 3)"))
        self.SpGrpComboBox.setItemText(147, _translate("stdbMainwindow", "147 (P -3)"))
        self.SpGrpComboBox.setItemText(148, _translate("stdbMainwindow", "148 (R -3)"))
        self.SpGrpComboBox.setItemText(149, _translate("stdbMainwindow", "149 (P 3 1 2)"))
        self.SpGrpComboBox.setItemText(150, _translate("stdbMainwindow", "150 (P 3 2 1)"))
        self.SpGrpComboBox.setItemText(151, _translate("stdbMainwindow", "151 (P 31 1 2)"))
        self.SpGrpComboBox.setItemText(152, _translate("stdbMainwindow", "152 (P 31 2 1)"))
        self.SpGrpComboBox.setItemText(153, _translate("stdbMainwindow", "153 (P 32 1 2)"))
        self.SpGrpComboBox.setItemText(154, _translate("stdbMainwindow", "154 (P 32 2 1)"))
        self.SpGrpComboBox.setItemText(155, _translate("stdbMainwindow", "155 (R 3 2)"))
        self.SpGrpComboBox.setItemText(156, _translate("stdbMainwindow", "156 (P 3 m 1)"))
        self.SpGrpComboBox.setItemText(157, _translate("stdbMainwindow", "157 (P 3 1 m)"))
        self.SpGrpComboBox.setItemText(158, _translate("stdbMainwindow", "158 (P 3 c 1)"))
        self.SpGrpComboBox.setItemText(159, _translate("stdbMainwindow", "159 (P 3 1 c)"))
        self.SpGrpComboBox.setItemText(160, _translate("stdbMainwindow", "160 (R 3 m)"))
        self.SpGrpComboBox.setItemText(161, _translate("stdbMainwindow", "161 (R 3 c)"))
        self.SpGrpComboBox.setItemText(162, _translate("stdbMainwindow", "162 (P -3 1 m)"))
        self.SpGrpComboBox.setItemText(163, _translate("stdbMainwindow", "163 (P -3 1 c)"))
        self.SpGrpComboBox.setItemText(164, _translate("stdbMainwindow", "164 (P -3 m 1)"))
        self.SpGrpComboBox.setItemText(165, _translate("stdbMainwindow", "165 (P -3 c 1)"))
        self.SpGrpComboBox.setItemText(166, _translate("stdbMainwindow", "166 (R -3 m)"))
        self.SpGrpComboBox.setItemText(167, _translate("stdbMainwindow", "167 (R -3 c)"))
        self.SpGrpComboBox.setItemText(168, _translate("stdbMainwindow", "168 (P 6)"))
        self.SpGrpComboBox.setItemText(169, _translate("stdbMainwindow", "169 (P 61)"))
        self.SpGrpComboBox.setItemText(170, _translate("stdbMainwindow", "170 (P 65)"))
        self.SpGrpComboBox.setItemText(171, _translate("stdbMainwindow", "171 (P 62)"))
        self.SpGrpComboBox.setItemText(172, _translate("stdbMainwindow", "172 (P 64)"))
        self.SpGrpComboBox.setItemText(173, _translate("stdbMainwindow", "173 (P 63)"))
        self.SpGrpComboBox.setItemText(174, _translate("stdbMainwindow", "174 (P -6)"))
        self.SpGrpComboBox.setItemText(175, _translate("stdbMainwindow", "175 (P 6/m)"))
        self.SpGrpComboBox.setItemText(176, _translate("stdbMainwindow", "176 (P 63/m)"))
        self.SpGrpComboBox.setItemText(177, _translate("stdbMainwindow", "177 (P 6 2 2)"))
        self.SpGrpComboBox.setItemText(178, _translate("stdbMainwindow", "178 (P 61 2 2)"))
        self.SpGrpComboBox.setItemText(179, _translate("stdbMainwindow", "179 (P 65 2 2)"))
        self.SpGrpComboBox.setItemText(180, _translate("stdbMainwindow", "180 (P 62 2 2)"))
        self.SpGrpComboBox.setItemText(181, _translate("stdbMainwindow", "181 (P 64 2 2)"))
        self.SpGrpComboBox.setItemText(182, _translate("stdbMainwindow", "182 (P 63 2 2)"))
        self.SpGrpComboBox.setItemText(183, _translate("stdbMainwindow", "183 (P 6 m m)"))
        self.SpGrpComboBox.setItemText(184, _translate("stdbMainwindow", "184 (P 6 c c)"))
        self.SpGrpComboBox.setItemText(185, _translate("stdbMainwindow", "185 (P 63 c m)"))
        self.SpGrpComboBox.setItemText(186, _translate("stdbMainwindow", "186 (P 63 m c)"))
        self.SpGrpComboBox.setItemText(187, _translate("stdbMainwindow", "187 (P -6 m 2)"))
        self.SpGrpComboBox.setItemText(188, _translate("stdbMainwindow", "188 (P -6 c 2)"))
        self.SpGrpComboBox.setItemText(189, _translate("stdbMainwindow", "189 (P -6 2 m)"))
        self.SpGrpComboBox.setItemText(190, _translate("stdbMainwindow", "190 (P -6 2 c)"))
        self.SpGrpComboBox.setItemText(191, _translate("stdbMainwindow", "191 (P 6/m m m)"))
        self.SpGrpComboBox.setItemText(192, _translate("stdbMainwindow", "192 (P 6/m c c)"))
        self.SpGrpComboBox.setItemText(193, _translate("stdbMainwindow", "193 (P 63/m c m)"))
        self.SpGrpComboBox.setItemText(194, _translate("stdbMainwindow", "194 (P 63/m m c)"))
        self.SpGrpComboBox.setItemText(195, _translate("stdbMainwindow", "195 (P 2 3)"))
        self.SpGrpComboBox.setItemText(196, _translate("stdbMainwindow", "196 (F 2 3)"))
        self.SpGrpComboBox.setItemText(197, _translate("stdbMainwindow", "197 (I 2 3)"))
        self.SpGrpComboBox.setItemText(198, _translate("stdbMainwindow", "198 (P 21 3)"))
        self.SpGrpComboBox.setItemText(199, _translate("stdbMainwindow", "199 (I 21 3)"))
        self.SpGrpComboBox.setItemText(200, _translate("stdbMainwindow", "200 (P m -3)"))
        self.SpGrpComboBox.setItemText(201, _translate("stdbMainwindow", "201 (P n -3)"))
        self.SpGrpComboBox.setItemText(202, _translate("stdbMainwindow", "202 (F m -3)"))
        self.SpGrpComboBox.setItemText(203, _translate("stdbMainwindow", "203 (F d -3)"))
        self.SpGrpComboBox.setItemText(204, _translate("stdbMainwindow", "204 (I m -3)"))
        self.SpGrpComboBox.setItemText(205, _translate("stdbMainwindow", "205 (P a -3)"))
        self.SpGrpComboBox.setItemText(206, _translate("stdbMainwindow", "206 (I a -3)"))
        self.SpGrpComboBox.setItemText(207, _translate("stdbMainwindow", "207 (P 4 3 2)"))
        self.SpGrpComboBox.setItemText(208, _translate("stdbMainwindow", "208 (P 42 3 2)"))
        self.SpGrpComboBox.setItemText(209, _translate("stdbMainwindow", "209 (F 4 3 2)"))
        self.SpGrpComboBox.setItemText(210, _translate("stdbMainwindow", "210 (F 41 3 2)"))
        self.SpGrpComboBox.setItemText(211, _translate("stdbMainwindow", "211 (I 4 3 2)"))
        self.SpGrpComboBox.setItemText(212, _translate("stdbMainwindow", "212 (P 43 3 2)"))
        self.SpGrpComboBox.setItemText(213, _translate("stdbMainwindow", "213 (P 41 3 2)"))
        self.SpGrpComboBox.setItemText(214, _translate("stdbMainwindow", "214 (I 41 3 2)"))
        self.SpGrpComboBox.setItemText(215, _translate("stdbMainwindow", "215 (P -4 3 m)"))
        self.SpGrpComboBox.setItemText(216, _translate("stdbMainwindow", "216 (F -4 3 m)"))
        self.SpGrpComboBox.setItemText(217, _translate("stdbMainwindow", "217 (I -4 3 m)"))
        self.SpGrpComboBox.setItemText(218, _translate("stdbMainwindow", "218 (P -4 3 n)"))
        self.SpGrpComboBox.setItemText(219, _translate("stdbMainwindow", "219 (F -4 3 c)"))
        self.SpGrpComboBox.setItemText(220, _translate("stdbMainwindow", "220 (I -4 3 d)"))
        self.SpGrpComboBox.setItemText(221, _translate("stdbMainwindow", "221 (P m -3 m)"))
        self.SpGrpComboBox.setItemText(222, _translate("stdbMainwindow", "222 (P n -3 n)"))
        self.SpGrpComboBox.setItemText(223, _translate("stdbMainwindow", "223 (P m -3 n)"))
        self.SpGrpComboBox.setItemText(224, _translate("stdbMainwindow", "224 (P n -3 m)"))
        self.SpGrpComboBox.setItemText(225, _translate("stdbMainwindow", "225 (F m -3 m)"))
        self.SpGrpComboBox.setItemText(226, _translate("stdbMainwindow", "226 (F m -3 c)"))
        self.SpGrpComboBox.setItemText(227, _translate("stdbMainwindow", "227 (F d -3 m)"))
        self.SpGrpComboBox.setItemText(228, _translate("stdbMainwindow", "228 (F d -3 c)"))
        self.SpGrpComboBox.setItemText(229, _translate("stdbMainwindow", "229 (I m -3 m)"))
        self.SpGrpComboBox.setItemText(230, _translate("stdbMainwindow", "230 (I a -3 d)"))
        self.modifiedlabel.setText(_translate("stdbMainwindow", "Modified between"))
        self.CCDCNumLabel.setText(_translate("stdbMainwindow", "CCDC number"))
        self.MaintabWidget.setTabText(self.MaintabWidget.indexOf(self.adv_searchtab), _translate("stdbMainwindow", "Advanced Search"))
        self.lattCentComboBox.setItemText(0, _translate("stdbMainwindow", "Primitive (P)", "P"))
        self.lattCentComboBox.setItemText(1, _translate("stdbMainwindow", "A-centered (A)", "A"))
        self.lattCentComboBox.setItemText(2, _translate("stdbMainwindow", "B-centered (B)", "B"))
        self.lattCentComboBox.setItemText(3, _translate("stdbMainwindow", "C-centered (C)", "C"))
        self.lattCentComboBox.setItemText(4, _translate("stdbMainwindow", "Face-centered (F)", "F"))
        self.lattCentComboBox.setItemText(5, _translate("stdbMainwindow", "Body-centered (I)", "I"))
        self.lattCentComboBox.setItemText(6, _translate("stdbMainwindow", "Rhombohedral (R)", "R"))
        self.CSDpushButton.setText(_translate("stdbMainwindow", "Search"))
        self.latticeCenteringLabel.setText(_translate("stdbMainwindow", "Lattice centring"))
        self.cellSearchLabelCSD.setText(_translate("stdbMainwindow", "Cell Search"))
        self.CSDtreeWidget.setToolTip(_translate("stdbMainwindow", "<html><head/><body><p>Double-click to view structure details in web browser</p></body></html>"))
        self.CSDtreeWidget.setSortingEnabled(False)
        self.CSDtreeWidget.headerItem().setText(0, _translate("stdbMainwindow", "Formula"))
        self.CSDtreeWidget.headerItem().setText(1, _translate("stdbMainwindow", "a"))
        self.CSDtreeWidget.headerItem().setText(2, _translate("stdbMainwindow", "b"))
        self.CSDtreeWidget.headerItem().setText(3, _translate("stdbMainwindow", "c"))
        self.CSDtreeWidget.headerItem().setText(4, _translate("stdbMainwindow", "alpha"))
        self.CSDtreeWidget.headerItem().setText(5, _translate("stdbMainwindow", "beta"))
        self.CSDtreeWidget.headerItem().setText(6, _translate("stdbMainwindow", "gamma"))
        self.CSDtreeWidget.headerItem().setText(7, _translate("stdbMainwindow", "Space Group"))
        self.CSDtreeWidget.headerItem().setText(8, _translate("stdbMainwindow", "Identifier"))
        self.cellcheckExeLineEdit.setPlaceholderText(_translate("stdbMainwindow", "Locate the CellCheckCSD executable here"))
        self.cellcheckExePushButton.setText(_translate("stdbMainwindow", "CellcheckCSD Executable"))
        self.cellcheckLabel.setText(_translate("stdbMainwindow", "<html><head/><body><p>You need to <a href=\"https://www.ccdc.cam.ac.uk/community/csd-community/cellcheckcsd/\"><span style=\" text-decoration: underline; color:#0068da;\">download CellCheckCSD</span></a> in order to make this work.</p></body></html>"))
        self.MaintabWidget.setTabText(self.MaintabWidget.indexOf(self.CCDCSearchTab), _translate("stdbMainwindow", "CellCheckCSD"))
        self.actionExit.setText(_translate("stdbMainwindow", "Exit Program"))
        self.actionExit.setShortcut(_translate("stdbMainwindow", "Ctrl+Q"))
        self.actionUser_manual.setText(_translate("stdbMainwindow", "User Manual"))
        self.actionImport_file.setText(_translate("stdbMainwindow", "Open Database"))
        self.actionImport_directory.setText(_translate("stdbMainwindow", "Import Directory"))
        self.actionSave_Database.setText(_translate("stdbMainwindow", "Save Database"))
        self.actionSave_Database.setShortcut(_translate("stdbMainwindow", "Ctrl+S"))
        self.actionAdvanced_Search.setText(_translate("stdbMainwindow", "Advanced Search"))
        self.actionAbout_StructureDB.setText(_translate("stdbMainwindow", "About StructureDB"))
        self.actionClose_Database.setText(_translate("stdbMainwindow", "Close Database"))
        self.actionCopy_Unit_Cell.setText(_translate("stdbMainwindow", "Copy Unit Cell"))
        self.actionGo_to_All_CIF_Tab.setText(_translate("stdbMainwindow", "Go to All CIF Tab"))
        self.actionGo_to_All_CIF_Tab.setShortcut(_translate("stdbMainwindow", "Meta+A"))
from structurefinder.displaymol.molecule2D import MoleculeWidget
from structurefinder.gui.table_view import StructuresListTableView
